from configparser import ConfigParser

import taiga

_CONFIG_FILE = 'config.ini' # config file


def _valid_taiga_config(config: ConfigParser) -> (bool):
    '''
    Function for checking including taiga configuration in config file
    '''
    if 'taiga' in config.sections():
        taiga_dict = dict(config['taiga'])
        if (
            'host' in taiga_dict and \
            'username' in taiga_dict and \
            'password' in taiga_dict and \
            'project_slug' in taiga_dict
        ):
            return True
    return False

def _valid_wiki_config(config: ConfigParser) -> (bool):
    '''
    Function for checking including wiki configuration in config file
    '''
    if 'wiki' in config.sections():
        wiki_dict = dict(config['wiki'])
        if (
            'url' in wiki_dict and \
            'token' in wiki_dict and \
            'path' in wiki_dict
        ):
            return True
    return False

def read_config(config_filename: str) -> (ConfigParser):
    '''
    Function for checking existence needed parametres in config file
    '''
    config = ConfigParser()
    if config.read(config_filename) == []:
        raise Exception('Section in configuration not found')
    if not _valid_taiga_config(config):
        raise Exception('Unvalid data-format in Taiga\'s config')
    if not _valid_wiki_config(config):
        raise Exception('Unvalid data-format in Wiki\'s config')
    return config['taiga'], config['wiki']
    