from jinja2 import Template
from jinja2 import Environment
from jinja2 import FileSystemLoader
from gql import gql, Client
from gql.transport.requests import RequestsHTTPTransport

def _normalise_str(s):
    return s.replace('\\', '\\\\').replace('\n', '\\n').replace('\r', '')

class PageWriter():
    def __init__(
        self, wiki_config,
        person_template='person_page.tmpl',
        list_template='list_page.tmpl',
        query_template='query.tmpl'
    ):
        env = Environment(loader=FileSystemLoader('./'))
        self._user_template = env.get_template(person_template)
        self._list_template = env.get_template(list_template)
        self._query_template = env.get_template(query_template)
        self._path = wiki_config['path']
        sample_transport=RequestsHTTPTransport(
            url=wiki_config['url'],
            use_json=True,
            headers={
                'Authorization': 'Bearer ' + wiki_config['token'],
                'Content-type': 'application/json'
            }
        )
        self._client = Client(
            transport=sample_transport,
            fetch_schema_from_transport=True,
        )
    
    def write_person_page(self, person):
        content = self._user_template.render(person=person)
        query_text = self._query_template.render(
            content=_normalise_str(content),
            path=self._path + person.username,
            title=person.full_name
        )
        resp = self._client.execute(
            gql(query_text)
        )['pages']['create']['responseResult']
        
        link = ''
        if resp['succeeded']:
            link = './' + person.username
        person.set_link(link)
        return resp['succeeded'], resp['message']

    def write_list_page(self, persons_by_role, title='Список участников'):
        content = self._list_template.render(persons_by_role=persons_by_role)
        query_text = self._query_template.render(
            content=_normalise_str(content),
            path=self._path + 'list',
            title=title
        )
        resp = self._client.execute(
            gql(query_text)
        )['pages']['create']['responseResult']
        return resp['succeeded'], resp['message']
